package com.vendor.burn.ui.burners;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.Messages;
import com.vendor.burn.model.FlashType;
import com.vendor.burn.model.PartitionInfo;
import com.vendor.burn.model.PartitionItem;
import com.vendor.burn.model.define.IBurner;
import com.vendor.burn.model.devices.IAddressBurner;
import com.vendor.burn.model.devices.IBootBurner;
import com.vendor.burn.model.devices.burners.AbstractBurner;
import com.vendor.burn.ui.burners.FastbootComposite;
import java.io.File;
import java.util.List;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.events.DisposeListener;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.swt.widgets.TabItem;
import org.eclipse.swt.widgets.Text;

public class AddressComposite extends FastbootComposite implements SelectionListener {
  private Text lengthText;
  
  private Button eraseButton;
  
  private Button uploadButton;
  
  private Text addressText;
  
  private static String filePath;
  
  private static FlashType flashType;
  
  private long start;
  
  private long length;
  
  protected static final String LABEL_HEX = "(HEX)";
  
  public AddressComposite(Composite parent, int style, IBurner burner, TabItem tabItem2) {
    super(parent, style, burner, tabItem2);
  }
  
  protected void createAddressEditor(Composite parent) {
    Label label = new Label(parent, 0);
    label.setText(Messages.AddressComposite_Address);
    this.addressText = createHexText(parent);
    this.addressText.addListener(24, (Listener)new Object(this));
    this.addressText.addDisposeListener((DisposeListener)new Object(this));
    createHexLabel(parent);
    new Label(parent, 0);
  }
  
  protected void createContents(Composite parent) {
    createFlashTypeEditor(parent, flashType);
    createAddressEditor(parent);
    createLengthEditor(parent);
    createFileEditor(parent);
    createProgrammerFileText(parent);
    createButtonsControl(parent);
    initData();
  }
  
  protected void getPartitionData(PartitionInfo partitionInfo) {
    if (partitionInfo != null) {
      PartitionItem data = partitionInfo.getChildren().get(0);
      File programmerFile = partitionInfo.getProgrammerFile();
      String programmerFileStr = (partitionInfo.getProgrammerFile() != null) ? programmerFile.getPath() : "";
      if (this.programmerFileText != null) {
        this.programmerFileText.setText(programmerFileStr);
        ((AbstractBurner)getBurner()).setProgrammerFile(programmerFileStr);
      } 
      this.length = data.getLength();
      this.start = data.getStart();
      try {
        this.lengthText.setText(String.valueOf(Long.toHexString(this.length)));
        this.addressText.setText(String.valueOf(Long.toHexString(this.start)));
      } catch (NumberFormatException e) {
        MessageDialog.openError(getShell(), "Error", "Please check Length!!!");
      } 
      flashType = data.getFlashType();
      updateFlashType((Composite)this, flashType);
      if (this.flashCombo != null && !this.flashCombo.isDisposed()) {
        this.flashCombo.select(data.getChipID().ordinal());
        getBurner().setFlashId(data.getChipID());
      } 
      try {
        if (data.getFile() != null)
          filePath = data.getFile().getCanonicalPath(); 
      } catch (Exception exception) {}
      if (filePath != null)
        updateFileEditor((Composite)this, filePath); 
    } 
  }
  
  protected Text createHexText(Composite parent) {
    Text hexText = new Text(parent, 2048);
    GridData layoutData = new GridData(768);
    hexText.setLayoutData(layoutData);
    hexText.setTextLimit(10);
    hexText.addListener(25, (Listener)new HexVerifier());
    return hexText;
  }
  
  protected void createLengthEditor(Composite parent) {
    Label label = new Label(parent, 0);
    label.setText(Messages.AddressComposite_Length);
    this.lengthText = createHexText(parent);
    this.lengthText.addListener(24, (Listener)new Object(this));
    this.lengthText.addDisposeListener((DisposeListener)new Object(this));
    createHexLabel(parent);
    new Label(parent, 0);
  }
  
  protected void fillButtons(Composite buttonComp, List<Button> buttons) {
    this.burnButton = createButton(buttonComp, LABEL_BURN);
    this.burnButton.addListener(13, (Listener)new Object(this));
    this.eraseButton = createButton(buttonComp, LABEL_ERASE);
    this.eraseButton.addListener(13, (Listener)new Object(this));
    this.uploadButton = createButton(buttonComp, LABEL_UPLOAD);
    this.uploadButton.addListener(13, (Listener)new Object(this));
    buttons.add(this.burnButton);
    buttons.add(this.eraseButton);
    buttons.add(this.uploadButton);
  }
  
  protected void enableUI() {
    getUIAdapter().enableBoradChange();
    if (isDisposed())
      return; 
    enableButtons();
  }
  
  protected void enableButtons() {
    super.enableButtons();
    if (this.burnButton != null && !this.burnButton.isDisposed())
      this.burnButton.setEnabled(true); 
    if (this.eraseButton != null && !this.eraseButton.isDisposed())
      this.eraseButton.setEnabled(true); 
    if (this.uploadButton != null && !this.uploadButton.isDisposed())
      this.uploadButton.setEnabled(true); 
  }
  
  protected void disableUI() {
    getUIAdapter().disableBoradChange();
    if (isDisposed())
      return; 
    if (this.burnButton != null && !this.burnButton.isDisposed())
      this.burnButton.setEnabled(false); 
    if (this.eraseButton != null && !this.eraseButton.isDisposed())
      this.eraseButton.setEnabled(false); 
    if (this.uploadButton != null && !this.uploadButton.isDisposed())
      this.uploadButton.setEnabled(false); 
  }
  
  public IAddressBurner getBurner() {
    return (IAddressBurner)super.getBurner();
  }
  
  public void updateLength(long length) {
    String hexString = Long.toHexString(length);
    getBurner().setLength(hexString);
    if (this.lengthText == null || isDisposed())
      return; 
    this.lengthText.setText(getBurner().getLength());
  }
  
  protected void handleBrwoseFileCA() {
    FileDialog dialog = new FileDialog(getShell(), 4096);
    String text = this.programmerFileText.getText();
    if (!text.equals(""))
      dialog.setFileName(text); 
    String filePath = dialog.open();
    if (filePath != null) {
      this.programmerFileText.setText(filePath);
      File bootFile = new File(filePath);
      if (bootFile.exists())
        ((AbstractBurner)getBurner()).setProgrammerFile(filePath); 
    } 
  }
  
  protected void createProgrammerFileText(Composite parent) {
    Label programmerFileLabel = new Label(parent, 0);
    programmerFileLabel
      .setText(Messages.FastbootComposite_LABEL_PROGRAMER_FILE);
    this.programmerFileText = new Text(parent, 2048);
    GridData layoutData = new GridData(768);
    layoutData.horizontalSpan = 2;
    this.programmerFileText.setEnabled(false);
    this.programmerFileText.setLayoutData(layoutData);
    this.programmerFileText.addDisposeListener((DisposeListener)new Object(this));
    this.programmerFileBrowseButton = new Button(parent, 0);
    this.programmerFileBrowseButton.setLayoutData(new GridData());
    this.programmerFileBrowseButton.setText(LABEL_BROWSE);
    this.programmerFileBrowseButton.addListener(13, (Listener)new Object(this));
  }
  
  public void widgetSelected(SelectionEvent e) {
    getPartitionData((PartitionInfo)e.data);
  }
  
  public void widgetDefaultSelected(SelectionEvent e) {}
  
  private void createHexLabel(Composite parent) {
    Label label = new Label(parent, 0);
    label.setText("(HEX)");
    GridData layoutData = new GridData(512);
    label.setLayoutData(layoutData);
  }
}
